@@ -1,10 +1,7 @@
 package Yote;
 
-use strict;
-use warnings;
-
 use vars qw($VERSION);
-$VERSION = '0.0974';
+$VERSION = '0.089';
 
 1;
 
